@@ -52,19 +52,19 @@ if(length(namepars[idparsfix]) == 0) { fixstr = "nothing" } else { fixstr = name
 cat("You are fixing",fixstr,"\n")
 if(length(namepars[idparsnoshift]) == 0) { noshiftstr = "anything" } else { noshiftstr = namepars[idparsnoshift] }
 cat("You are not shifting",noshiftstr,"\n")
+cat("Optimizing the likelihood - this may take a while.","\n")
+flush.console()
 trparsopt = initparsopt/(1 + initparsopt)
 trparsfix = parsfix/(1 + parsfix)
+trparsfix[which(parsfix == Inf)] = 1
 pars2 = c(res,ddmodel,cond,btorph,0,tol,maxiter)
-flush.console()
 initloglik = dd_SR_loglik_choosepar(trparsopt = trparsopt,trparsfix = trparsfix,idparsopt = idparsopt,idparsfix = idparsfix,idparsnoshift = idparsnoshift,pars2 = pars2,brts = brts,missnumspec = missnumspec)
 cat("The likelihood for the initial parameter values is",initloglik,"\n")
 if(initloglik == -Inf)
 {
-   cat("The initial parameter values have a likelihood that is equal 0 or below machine precision. Try again with different initial values.\n")
+   cat("The initial parameter values have a likelihood that is equal to 0 or below machine precision. Try again with different initial values.\n")
    out2 = data.frame(row.names = "results",lambda_1 = -1, mu_1 = -1, K_1 = -1, lambda_2 = -1, mu_2 = -1, K_2 = -1, t_shift = -1, loglik = -1, df = -1, conv = -1)
 } else {
-cat("Optimizing the likelihood - this may take a while.","\n")
-flush.console()
 #code up to DDD v1.6: out = optimx2(trparsopt,dd_SR_loglik_choosepar,hess=NULL,method = "Nelder-Mead",hessian = FALSE,control = list(maximize = TRUE,abstol = pars2[8],reltol = pars2[7],trace = 0,starttests = FALSE,kkt = FALSE),trparsfix = trparsfix,idparsopt = idparsopt,idparsfix = idparsfix,idparsnoshift = idparsnoshift,brts = brts,pars2 = pars2,missnumspec = missnumspec)
 out = dd_SR_simplex(trparsopt,idparsopt,trparsfix,idparsfix,idparsnoshift,pars2,brts,missnumspec)
 if(out$conv > 0)
